﻿namespace WindowsFormsTest_Weiterentwicklung
{
    using System;
    using System.Windows.Forms;

    public partial class Form1 : Form
    {
        // Die eingegebene Nummer speichern wir hier.
        private int _number;

        // Ein Boolean, der bestimmt, ob der Timer pausiert wurde.
        private bool _isPaused;

        public Form1()
        {
            InitializeComponent();

            // Hier könnte man auch noch das Intervall des Timers setzen
            // z.B.: myTimer.Interval = 1000;
            // Dies ist allerdings schon in der UI geschehen und muss hier
            // nicht nochmals gemacht werden.
        }

        // Im Tick-Handler wird nichts anderes gemacht,
        // als die Zahl zu verkleinern und ggf. den Timer zu stoppen.
        private void OnTimerTick(object sender, EventArgs e)
        {
            if ( _number > 0 )
            {
                _number--;
                progressBar.Value++; 
                textboxEingabe.Text = _number.ToString();
            }

            // Wenn die Zahl gleich 0 ist, stoppt der Timer.
            // Die Eingabe und die Progressbar werden aber nicht zurückgesetzt.
            if ( _number == 0 )
            {
                Reset( false );
            }
        }

        private void OnBtnStartClick(object sender, EventArgs e)
        {
            // Prüfen, ob der Timer vorher pausiert wurde.
            // Wenn ja: den Timer wieder starten und den Button "umlabeln", sonst nichts.
            if ( _isPaused )
            {
                myTimer.Start();
                btnStart.Text = "PAUSE";
                _isPaused = false;
                return;
            }

            // Der Fall "Pause"
            // D.h. der Timer läuft und soll nun pausiert werden.
            if ( myTimer.Enabled )
            {
                myTimer.Stop();
                _isPaused = true;
                btnStart.Text = "WEITER";
                return;
            }

            // Die Zahl parsen.
            // TryParse gibt false zurück, wenn die Eingabe keine Ganzzahl ist.
            bool isNumber = int.TryParse( textboxEingabe.Text, out _number );
            if ( !isNumber || _number < 1 )
            {
                // falls in der Textbox keine gültige Zahl steht, zeigen wir einen Fehler-Dialog
                MessageBox.Show( "Ungültige Eingabe! Bite geben Sie eine positive, ganze Zahl ein.", "Fehler", MessageBoxButtons.OK, MessageBoxIcon.Error );
                return;
            }

            // Timer starten.
            // Rechnungen bzgl. des Werts der Progressbar kann man sich sparen,
            // wenn man das Maximum gleich der eingebenen Zahl setzt.
            progressBar.Maximum = _number;
            btnStart.Text = "PAUSE";
            textboxEingabe.ReadOnly = true;
            myTimer.Start();
        }

        // Der Button "Stop" setzt alles zurück.
        private void OnBtnStopClick(object sender, EventArgs e)
        {
            Reset( true );
        }

        private void OnTextBoxClick(object sender, EventArgs e)
        {
            textboxEingabe.SelectAll();
        }

        // Eingabe zurücksetzen.
        private void Reset( bool resetProgress )
        {
            myTimer.Stop();
            textboxEingabe.ReadOnly = false;
            btnStart.Text = "START";

            // Bestimmt, ob auch der Inhalt der TextBox und die Progressbar
            // zurückgesetzt werden sollen.
            if ( resetProgress )
            {
                textboxEingabe.Text = "[Bitte Zahl eingeben]";
                progressBar.Value = 0;
            }
        }
    }
}
